@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2017-01-09'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010001;
 use strict;
@@ -162,6 +162,7 @@ sub munge_files {
             (per_arg_yaml => $self->per_arg_yaml) x !!defined($self->per_arg_yaml),
             (validate_args => $self->validate_args) x !!defined($self->validate_args),
             (pack_deps => $self->pack_deps) x !!defined($self->pack_deps),
+            pod => 0, # will be generated by PWP:Rinci
         );
         #use DD; dd \%gen_args;
         $res = gen_pericmd_script(%gen_args);
@@ -217,7 +218,7 @@ sub munge_files {
     # natively.
     if ($res->[3]{'func.cmdline_module_inlined'}) {
         require App::GenPericmdCompleterScript;
-        my $compres = App::GenPericmdCompleterScript::gen_perinci_cmdline_completer_script(
+        my $compres = App::GenPericmdCompleterScript::gen_pericmd_completer_script(
             url => $self->url,
             subcommands => $subcommands,
             #default_format => $self->default_format,
@@ -253,7 +254,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.37 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-09.
+This document describes version 0.38 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-12.
 
 =head1 SYNOPSIS
 
@@ -445,7 +446,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
 
 =head1 BUGS
 
